@@ -8,21 +8,25 @@
 # This file is part of gunicorn released under the MIT license.
 # See the NOTICE for more information.
 
-import gunicorn
-import gunicorn.app.base
+from __future__ import unicode_literals
+
 import multiprocessing
 
+import gunicorn.app.base
+
+from gunicorn.six import iteritems
+
+
 def number_of_workers():
     return (multiprocessing.cpu_count() * 2) + 1
 
 
 def handler_app(environ, start_response):
-    response_body = 'Works fine'
+    response_body = b'Works fine'
     status = '200 OK'
 
     response_headers = [
         ('Content-Type', 'text/plain'),
-        ('Content-Lenfth', str(len(response_body))),
     ]
 
     start_response(status, response_headers)
@@ -31,24 +35,16 @@ def handler_app(environ, start_response):
 
 
 class StandaloneApplication(gunicorn.app.base.BaseApplication):
+
     def __init__(self, app, options=None):
-        self.options = dict(options or {})
+        self.options = options or {}
         self.application = app
         super(StandaloneApplication, self).__init__()
 
     def load_config(self):
-        tmp_config = map(
-            lambda item: (item[0].lower(), item[1]),
-            self.options.iteritems()
-        )
-
-        config = dict(
-            (key, value)
-            for key, value in tmp_config
-            if key in self.cfg.settings and value is not None
-        )
-
-        for key, value in config.iteritems():
+        config = dict([(key, value) for key, value in iteritems(self.options)
+                       if key in self.cfg.settings and value is not None])
+        for key, value in iteritems(config):
             self.cfg.set(key.lower(), value)
 
     def load(self):
