@@ -5,27 +5,23 @@
 #
 # Example code from Eventlet sources
 
-import os
-import pprint
 from wsgiref.validate import validator
-import sys
 
 from gunicorn import __version__
-#@validator
+
+
+@validator
 def app(environ, start_response):
     """Simplest possible application object"""
 
-    errors = environ['wsgi.errors']
-#    pprint.pprint(('ENVIRON', environ), stream=errors)
-
     data = b'Hello, World!\n'
     status = '200 OK'
 
     response_headers = [
-        ('Content-type','text/plain'),
+        ('Content-type', 'text/plain'),
         ('Content-Length', str(len(data))),
         ('X-Gunicorn-Version', __version__),
-        ("Test", "test тест"),
+        #("Test", "test тест"),
     ]
     start_response(status, response_headers)
     return iter([data])
