@@ -7,15 +7,12 @@ from __future__ import print_function
 
 import email.utils
 import fcntl
-import grp
 import io
 import os
 import pkg_resources
 import pwd
 import random
-import resource
 import socket
-import stat
 import sys
 import textwrap
 import time
@@ -23,21 +20,16 @@ import traceback
 import inspect
 import errno
 import warnings
-import cgi
+import logging
+import re
 
+from gunicorn import _compat
 from gunicorn.errors import AppImportError
 from gunicorn.six import text_type
 from gunicorn.workers import SUPPORTED_WORKERS
 
-MAXFD = 1024
 REDIRECT_TO = getattr(os, 'devnull', '/dev/null')
 
-timeout_default = object()
-
-CHUNK_SIZE = (16 * 1024)
-
-MAX_BODY = 1024 * 132
-
 # Server and Date aren't technically hop-by-hop
 # headers, but they are in the purview of the
 # origin server which the WSGI spec says we should
@@ -54,6 +46,7 @@ hop_headers = set("""
 
 try:
     from setproctitle import setproctitle
+
     def _setproctitle(title):
         setproctitle("gunicorn: %s" % title)
 except ImportError:
@@ -69,7 +62,7 @@ except ImportError:
         if not hasattr(package, 'rindex'):
             raise ValueError("'package' not set to a string")
         dot = len(package)
-        for x in range(level, 1, -1):
+        for _ in range(level, 1, -1):
             try:
                 dot = package.rindex('.', 0, dot)
             except ValueError:
@@ -147,13 +140,30 @@ def load_class(uri, default="gunicorn.workers.sync.SyncWorker",
         return getattr(mod, klass)
 
 
-def set_owner_process(uid, gid):
+def get_username(uid):
+    """ get the username for a user id"""
+    return pwd.getpwuid(uid).pw_name
+
+
+def set_owner_process(uid, gid, initgroups=False):
     """ set user and group of workers processes """
+
     if gid:
+        if uid:
+            try:
+                username = get_username(uid)
+            except KeyError:
+                initgroups = False
+
         # versions of python < 2.6.2 don't manage unsigned int for
         # groups like on osx or fedora
         gid = abs(gid) & 0x7FFFFFFF
-        os.setgid(gid)
+
+        if initgroups:
+            os.initgroups(username, gid)
+        elif gid != os.getgid():
+            os.setgid(gid)
+
     if uid:
         os.setuid(uid)
 
@@ -181,7 +191,7 @@ if sys.platform.startswith("win"):
         # required when contention occurs.
         timeout = 0.001
         while timeout < 1.0:
-            # Note we are only testing for the existance of the file(s) in
+            # Note we are only testing for the existence of the file(s) in
             # the contents of the directory regardless of any security or
             # access rights.  If we have made it this far, we have sufficient
             # permissions to do that much using Python's equivalent of the
@@ -189,7 +199,7 @@ if sys.platform.startswith("win"):
             # Other Windows APIs can fail or give incorrect results when
             # dealing with files that are pending deletion.
             L = os.listdir(dirname)
-            if not (L if waitall else name in L):
+            if not L if waitall else name in L:
                 return
             # Increase the timeout and try again
             time.sleep(timeout)
@@ -223,11 +233,8 @@ def is_ipv6(addr):
 
 
 def parse_address(netloc, default_port=8000):
-    if netloc.startswith("unix://"):
-        return netloc.split("unix://")[1]
-
-    if netloc.startswith("unix:"):
-        return netloc.split("unix:")[1]
+    if re.match(r'unix:(//)?', netloc):
+        return re.split(r'unix:(//)?', netloc)[-1]
 
     if netloc.startswith("tcp://"):
         netloc = netloc.split("tcp://")[1]
@@ -253,12 +260,6 @@ def parse_address(netloc, default_port=8000):
         port = default_port
     return (host, port)
 
-def get_maxfd():
-    maxfd = resource.getrlimit(resource.RLIMIT_NOFILE)[1]
-    if (maxfd == resource.RLIM_INFINITY):
-        maxfd = MAXFD
-    return maxfd
-
 
 def close_on_exec(fd):
     flags = fcntl.fcntl(fd, fcntl.F_GETFD)
@@ -270,6 +271,7 @@ def set_non_blocking(fd):
     flags = fcntl.fcntl(fd, fcntl.F_GETFL) | os.O_NONBLOCK
     fcntl.fcntl(fd, fcntl.F_SETFL, flags)
 
+
 def close(sock):
     try:
         sock.close()
@@ -314,11 +316,6 @@ def write_nonblock(sock, data, chunked=False):
         return write(sock, data, chunked)
 
 
-def writelines(sock, lines, chunked=False):
-    for line in list(lines):
-        write(sock, line, chunked)
-
-
 def write_error(sock, status_int, reason, mesg):
     html = textwrap.dedent("""\
     <html>
@@ -330,7 +327,7 @@ def write_error(sock, status_int, reason, mesg):
         %(mesg)s
       </body>
     </html>
-    """) % {"reason": reason, "mesg": cgi.escape(mesg)}
+    """) % {"reason": reason, "mesg": _compat.html_escape(mesg)}
 
     http = textwrap.dedent("""\
     HTTP/1.1 %s %s\r
@@ -342,10 +339,6 @@ def write_error(sock, status_int, reason, mesg):
     write_nonblock(sock, http.encode('latin1'))
 
 
-def normalize_name(name):
-    return "-".join([w.lower().capitalize() for w in name.split("-")])
-
-
 def import_app(module):
     parts = module.split(":", 1)
     if len(parts) == 1:
@@ -364,10 +357,13 @@ def import_app(module):
 
     mod = sys.modules[module]
 
+    is_debug = logging.root.level == logging.DEBUG
     try:
-        app = eval(obj, mod.__dict__)
+        app = eval(obj, vars(mod))
     except NameError:
-        raise AppImportError("Failed to find application: %r" % module)
+        if is_debug:
+            traceback.print_exception(*sys.exc_info())
+        raise AppImportError("Failed to find application object %r in %r" % (obj, module))
 
     if app is None:
         raise AppImportError("Failed to find application object: %r" % obj)
@@ -419,7 +415,7 @@ def daemonize(enable_stdio_inheritance=False):
         os.umask(0o22)
 
         # In both the following any file descriptors above stdin
-        # stdout and stderr are left untouched. The inheritence
+        # stdout and stderr are left untouched. The inheritance
         # option simply allows one to have output go to a file
         # specified by way of shell redirection when not wanting
         # to use --error-log option.
@@ -537,6 +533,7 @@ def warn(msg):
 
 
 def make_fail_app(msg):
+    msg = to_bytestring(msg)
 
     def app(environ, start_response):
         start_response("500 Internal Server Error", [
@@ -546,3 +543,15 @@ def make_fail_app(msg):
         return [msg]
 
     return app
+
+
+def split_request_uri(uri):
+    if uri.startswith("//"):
+        # When the path starts with //, urlsplit considers it as a
+        # relative uri while the RFC says we should consider it as abs_path
+        # http://www.w3.org/Protocols/rfc2616/rfc2616-sec5.html#sec5.1.2
+        # We use temporary dot prefix to workaround this behaviour
+        parts = _compat.urlsplit("." + uri)
+        return parts._replace(path=parts.path[1:])
+
+    return _compat.urlsplit(uri)
